import {
  CreateSightPage,
  DevicesPage,
  EditSightPage,
  LoginPage,
  MainPage,
  SightPage,
} from "@pages";
import { authStore, createSightStore, editSightStore } from "@shared";
import { Layout } from "@widgets";
import { runInAction } from "mobx";
import { useEffect } from "react";

import { Navigate, Outlet, Route, Routes, useLocation } from "react-router-dom";

const PublicRoute = ({ children }: { children: React.ReactNode }) => {
  const { isAuthenticated } = authStore;
  if (isAuthenticated) {
    return <Navigate to="/sight" />;
  }
  return children;
};

const ProtectedRoute = ({ children }: { children: React.ReactNode }) => {
  const { isAuthenticated } = authStore;
  const pathname = useLocation();
  if (!isAuthenticated) {
    return <Navigate to="/login" />;
  }
  if (pathname.pathname === "/") {
    return <Navigate to="/sight" />;
  }
  return children;
};

export const Router = () => {
  const pathname = useLocation();

  useEffect(() => {
    editSightStore.clearSightInfo();
    createSightStore.clearCreateSight();
    runInAction(() => {
      editSightStore.hasLoadedCommon = false;
    });
  }, [pathname]);

  return (
    <Routes>
      <Route
        path="/login"
        element={
          <PublicRoute>
            <LoginPage />
          </PublicRoute>
        }
      />

      {/* Protected routes with layout */}
      <Route
        path="/"
        element={
          <ProtectedRoute>
            <Layout>
              <Outlet />
            </Layout>
          </ProtectedRoute>
        }
      >
        <Route index element={<MainPage />} />
        <Route path="sight" element={<SightPage />} />
        <Route path="sight/:id" element={<EditSightPage />} />
        <Route path="sight/create" element={<CreateSightPage />} />
        <Route path="devices" element={<DevicesPage />} />
      </Route>
    </Routes>
  );
};
